try_language

Function try_language 

pub fn try_language() -> Result<Language, TreeSitterError>
Returns the tree-sitter Language for PL/SQL, with error handling

This is a fallible alternative to language() for use cases that need to handle grammar loading errors gracefully.

Errors

Returns an error if the loaded grammar fails validation. See sqry_tree_sitter_support::TreeSitterError for possible error variants.